@@ -13,8 +13,12 @@ from .types import *
 __title__ = 'Savify'
 __author__ = """Laurence Rawlings"""
 __email__ = 'contact@laurencerawlings.com'
-__version__ = '2.0.6'
+__version__ = '2.0.8'
 __license__ = 'MIT'
 __docformat__ = 'restructuredtext en'
 
 __all__ = ['savify', 'types']
+
+def cli():
+    from .cli import main
+    main()
